==> kiteclib-0.0.2.tgz: package/lib/util/UtilString.js <==
//import { MessageDigest } from '../../../java/security/MessageDigest'
//import { NoSuchAlgorithmException } from '../../../java/security/NoSuchAlgorithmException'
//import { UnsupportedEncodingException } from '../../../java/io/UnsupportedEncodingException'
//module jp.kitec.lib.util
/**
 * String関係のユーティリティ
 * @author kawae
 * @since 2005/03/16
**/
export class UtilString {
    /**
     * タブをスペースに変更
     * @param s
     * @return
     * @author kawae
     * @since 2005/03/16
    **/
    static tab2space(s) {
        if (s == null)
            return s;
        while (s.indexOf('\t') >= 0) {
            var index = s.indexOf('\t');
            var length = s.length;
            var s1 = s.substring(0, index);
            var s2 = (index + 1) >= length ? "" : s.substring(index + 1);
            var s1length = 0;
            s1length = s1.length;
            for (var i__0 = 0; i__0 < s1.length; i__0++) {
                var c = s1.charCodeAt(i__0);
                if (!UtilString.isHankaku(c))
                    s1length += 1;
            }
            var spacecount = 8 - s1length % 8;
            var sb = "";
            sb += s1;
            for (var i__1 = 0; i__1 < spacecount; i__1++)
                sb += " ";
            sb += s2;
            s = sb;
        }
        return s;
    }
    /**
     * 指定された半角数字の文字列を、全角数字の文字列へ変換する。
     * 数字以外の場合、全角へは変換されず、もとの文字が設定される。
     * @param str	半角数字の文字列
     * @return 全角数字の文字列
     * @since   2003/02/13
     * @author  Kawae
     * @version 2003/02/13
    **/
    static getZenkakuNumberExPeriod(str) {
        if (!UtilString.ZENKAKU_TABLE) {
            UtilString.ZENKAKU_TABLE = new Map([['０', '0'],
                ['１', '1'],
                ['２', '2'],
                ['３', '3'],
                ['４', '4'],
                ['５', '5'],
                ['６', '6'],
                ['７', '7'],
                ['８', '8'],
                ['９', '9']]);
        }
        var c = "";
        for (var i = 0; i < str.length; i++) {
            var cc = str.charAt(i);
            var z = UtilString.ZENKAKU_TABLE.get(cc);
            if (z) {
                c += z;
            }
            else
                c += cc;
        }
        return c;
    }
    /**
     * 半角か確認
     * @param c
     * @return
     * @author kawae
     * @since 2005/01/06
    **/
    static isHankaku(c) {
        if (UtilString.isHankakuKana(c))
            return true;
        else if (c < 0x7F)
            return true;
        return false;
    }
    /**
     * 半角カナか確認
     * @param c
     * @return
     * @author kawae
     * @since 2005/01/06
    **/
    static isHankakuKana(c) {
        return (c > 0xff60 && c <= 0xff9f);
    }
    /**
     * 全角カナか確認
     * @author kawae
     * @since 2005/01/06
    **/
    static isZenkakuKana(c) {
        return (c > 0x30a0 && c <= 0x30f4);
    }
    /**
     * 全角ひらがなか確認
     * @author kawae
     * @since 2005/01/06
    **/
    static isFullHiraKana(c) {
        return (c > 0x3040 && c <= 0x3094);
    }
    /**
     * 半角数字か確認
     * @param c
     * @return
     * @author kawae
     * @since 2005/01/06
    **/
    static isHankakuSuuji(c) {
        return c >= '0'.charCodeAt(0) && c <= '9'.charCodeAt(0);
    }
    /**
     * 全角数字か確認
     * @param c
     * @return
     * @author kawae
     * @since 2005/01/06
    **/
    static isZenkakuSuuji(c) {
        return c >= '０'.charCodeAt(0) && c <= '９'.charCodeAt(0);
    }
    /**
     * 特定のエンコーディングで利用出来る文字か確認
     * @param s
     * @return
     * @author kawae
     * @since 2006/01/12
    **/
    //static isEnableEncChar(s: number, enc: string): boolean {
    //    return UtilString.isEnableEncChar(Character.toString(s), enc);
    //}
    /**
     * 特定のエンコーディングで利用出来る文字か確認
     * @param s
     * @return
     * @author kawae
     * @since 2006/01/12
    **/
    //static isEnableEncChar(s: string, enc: string): boolean {
    //    try {
    //        var sjis: string = new string(s.getBytes(enc), enc);
    //        return s.equalsIgnoreCase(sjis);
    //    }
    //    catch (expected: UnsupportedEncodingException) {
    //    }
    //    return false;
    //}
    /**
     * 文字列が異なるか確認
     * @param s1
     * @param s2
     * @return
     * @author kawae
     * @since 2004/09/26
    **/
    //static isDiff(s1: string, s2: string): boolean {
    //    return UtilString.isDiff(s1, s2, false);
    //}
    static isDiff(s1, s2, compareUpperLower = false) {
        if ((s1 == null) != (s2 == null))
            return true;
        if (s1 == null)
            return false;
        if (compareUpperLower)
            return s1 !== s2;
        else
            return s1.toLowerCase() !== s2.toLowerCase();
    }
    /**
     * 文字配列が異なるか確認
     * @param s1
     * @param s2
     * @return
     * @author kawae
     * @since 2004/09/26
    **/
    //static isDiffArray(s1: string[], s2: string[]): boolean {
    //    return UtilString.isDiff(s1, s2, false);
    //}
    static isDiffArray(s1, s2, compareUpperLower = false) {
        if ((s1 == null) != (s2 == null))
            return true;
        if (s1 == null)
            return false;
        if (s1.length != s2.length)
            return true;
        for (var i = 0; i < s1.length; i++) {
            if (UtilString.isDiff(s1[i], s2[i], compareUpperLower))
                return true;
        }
        return false;
    }
    static bin2dec(s) {
        var result = 0;
        for (var i = 0; i < s.length; i++) {
            var c = s.charCodeAt(s.length - i - 1);
            if (c == '1'.charCodeAt(0))
                result |= 1 << i;
        }
        return result;
    }
}
//# sourceMappingURL=UtilString.js.map

==> kiteclib-0.0.3.tgz: package/lib/util/UtilString.js <==
//import { MessageDigest } from '../../../java/security/MessageDigest'
//import { NoSuchAlgorithmException } from '../../../java/security/NoSuchAlgorithmException'
//import { UnsupportedEncodingException } from '../../../java/io/UnsupportedEncodingException'
//module jp.kitec.lib.util
/**
 * String関係のユーティリティ
 * @author kawae
 * @since 2005/03/16
**/
export class UtilString {
    /**
     * タブをスペースに変更
     * @param s
     * @return
     * @author kawae
     * @since 2005/03/16
    **/
    static tab2space(s) {
        if (s == null)
            return s;
        while (s.indexOf('\t') >= 0) {
            var index = s.indexOf('\t');
            var length = s.length;
            var s1 = s.substring(0, index);
            var s2 = (index + 1) >= length ? "" : s.substring(index + 1);
            var s1length = 0;
            s1length = s1.length;
            for (var i__0 = 0; i__0 < s1.length; i__0++) {
                var c = s1.charCodeAt(i__0);
                if (!UtilString.isHankaku(c))
                    s1length += 1;
            }
            var spacecount = 8 - s1length % 8;
            var sb = "";
            sb += s1;
            for (var i__1 = 0; i__1 < spacecount; i__1++)
                sb += " ";
            sb += s2;
            s = sb;
        }
        return s;
    }
    /**
     * 指定された半角数字の文字列を、全角数字の文字列へ変換する。
     * 数字以外の場合、全角へは変換されず、もとの文字が設定される。
     * @param str	半角数字の文字列
     * @return 全角数字の文字列
     * @since   2003/02/13
     * @author  Kawae
     * @version 2003/02/13
    **/
    static getZenkakuNumberExPeriod(str) {
        if (!UtilString.ZENKAKU_TABLE) {
            UtilString.ZENKAKU_TABLE = new Map([['０', '0'],
                ['１', '1'],
                ['２', '2'],
                ['３', '3'],
                ['４', '4'],
                ['５', '5'],
                ['６', '6'],
                ['７', '7'],
                ['８', '8'],
                ['９', '9']]);
        }
        var c = "";
        for (var i = 0; i < str.length; i++) {
            var cc = str.charAt(i);
            let z = cc;
            for (let e of UtilString.ZENKAKU_TABLE) {
                if (e[1] === cc) {
                    z = e[0];
                }
            }
            c += z;
        }
        return c;
    }
    /**
     * 半角か確認
     * @param c
     * @return
     * @author kawae
     * @since 2005/01/06
    **/
    static isHankaku(c) {
        if (UtilString.isHankakuKana(c))
            return true;
        else if (c < 0x7F)
            return true;
        return false;
    }
    /**
     * 半角カナか確認
     * @param c
     * @return
     * @author kawae
     * @since 2005/01/06
    **/
    static isHankakuKana(c) {
        return (c > 0xff60 && c <= 0xff9f);
    }
    /**
     * 全角カナか確認
     * @author kawae
     * @since 2005/01/06
    **/
    static isZenkakuKana(c) {
        return (c > 0x30a0 && c <= 0x30f4);
    }
    /**
     * 全角ひらがなか確認
     * @author kawae
     * @since 2005/01/06
    **/
    static isFullHiraKana(c) {
        return (c > 0x3040 && c <= 0x3094);
    }
    /**
     * 半角数字か確認
     * @param c
     * @return
     * @author kawae
     * @since 2005/01/06
    **/
    static isHankakuSuuji(c) {
        return c >= '0'.charCodeAt(0) && c <= '9'.charCodeAt(0);
    }
    /**
     * 全角数字か確認
     * @param c
     * @return
     * @author kawae
     * @since 2005/01/06
    **/
    static isZenkakuSuuji(c) {
        return c >= '０'.charCodeAt(0) && c <= '９'.charCodeAt(0);
    }
    /**
     * 特定のエンコーディングで利用出来る文字か確認
     * @param s
     * @return
     * @author kawae
     * @since 2006/01/12
    **/
    //static isEnableEncChar(s: number, enc: string): boolean {
    //    return UtilString.isEnableEncChar(Character.toString(s), enc);
    //}
    /**
     * 特定のエンコーディングで利用出来る文字か確認
     * @param s
     * @return
     * @author kawae
     * @since 2006/01/12
    **/
    //static isEnableEncChar(s: string, enc: string): boolean {
    //    try {
    //        var sjis: string = new string(s.getBytes(enc), enc);
    //        return s.equalsIgnoreCase(sjis);
    //    }
    //    catch (expected: UnsupportedEncodingException) {
    //    }
    //    return false;
    //}
    /**
     * 文字列が異なるか確認
     * @param s1
     * @param s2
     * @return
     * @author kawae
     * @since 2004/09/26
    **/
    //static isDiff(s1: string, s2: string): boolean {
    //    return UtilString.isDiff(s1, s2, false);
    //}
    static isDiff(s1, s2, compareUpperLower = false) {
        if ((s1 == null) != (s2 == null))
            return true;
        if (s1 == null)
            return false;
        if (compareUpperLower)
            return s1 !== s2;
        else
            return s1.toLowerCase() !== s2.toLowerCase();
    }
    /**
     * 文字配列が異なるか確認
     * @param s1
     * @param s2
     * @return
     * @author kawae
     * @since 2004/09/26
    **/
    //static isDiffArray(s1: string[], s2: string[]): boolean {
    //    return UtilString.isDiff(s1, s2, false);
    //}
    static isDiffArray(s1, s2, compareUpperLower = false) {
        if ((s1 == null) != (s2 == null))
            return true;
        if (s1 == null)
            return false;
        if (s1.length != s2.length)
            return true;
        for (var i = 0; i < s1.length; i++) {
            if (UtilString.isDiff(s1[i], s2[i], compareUpperLower))
                return true;
        }
        return false;
    }
    static bin2dec(s) {
        var result = 0;
        for (var i = 0; i < s.length; i++) {
            var c = s.charCodeAt(s.length - i - 1);
            if (c === '1'.charCodeAt(0))
                result |= 1 << i;
        }
        return result;
    }
}
//# sourceMappingURL=UtilString.js.map
